@@ -4,15 +4,18 @@ use warnings;
 use base qw/Moxy::Plugin/;
 
 # HTML全体の横幅をUAの画面サイズに合わせる
-sub response_filter:Hook('response_filter') {
+sub response_filter :Hook {
     my ($class, $context, $args) = @_;
-    return if $args->{mobile_attribute}->is_non_mobile;
-    return if $args->{mobile_attribute}->is_airh_phone;
+    my $attr = $args->{mobile_attribute};
+    return if $attr->is_non_mobile;
 
-    my $display = $args->{mobile_attribute}->display;
-    my $header = sprintf(
-        q{<div style="border: 1px black solid; width: %dpx">}, $display->width
-    );
+    # HTTP::MobileAttribute::Plugin::Display は AirHPhone に対応していない。
+    # が、ディスプレイ幅の指定がないと利用に耐えないので、現行機種のほとんどが 320px であることが下記 URL より確認できるので
+    # http://www.willcom-inc.com/ja/lineup/spec/voice/index.html
+    # 320px 固定にしておく。だれか Willcom が大好きでたまらないような人があらわれたら対応してください。
+    my $width = $attr->is_airh_phone ? 320 : $attr->display->width;
+
+    my $header = qq!<div style="border: 1px black solid; width: ${width}px; margin: 0 auto;float: left;">!;
 
     my $content = $args->{response}->content;
     $content =~ s!(<body[^>]*>)!$1$header!i;
